import sys
import configparser
import platform
import os

from PyQt5.QtWidgets import QApplication, QWidget, QVBoxLayout, QTabWidget, QLabel
from PyQt5.QtCore import Qt

from ui.mount import mount_tab
from ui.folder import folder_tab
from ui.create_json import create_tab
from ui.edit_json import edit_tab
from ui.tbd import tbd_tab
from ui.edit_config import config_tab

class TabbedGUI(QWidget):
    def __init__(self):
        super().__init__()
        self.initUI()

    def initUI(self):
        self.setWindowTitle('Research Desktop - A "Noob@FDM" App')
        self.layout = QVBoxLayout()

        # Create a title label
        os_name = platform.system()
        self.title = QLabel(f"Operating System: {os_name}")
        self.title.setAlignment(Qt.AlignCenter)
        self.layout.addWidget(self.title)

        # Create the tab widget
        self.tabs = QTabWidget()
        self.layout.addWidget(self.tabs)

        # Create the tabs
        self.tabs.addTab(mount_tab(config), "\u2460 Mount share")
        self.tabs.addTab(folder_tab(), "\u2461 Create folder")
        self.tabs.addTab(create_tab(), "\u2462 Create JSON")
        self.tabs.addTab(edit_tab(), "\u2463 Edit JSON")
        self.tabs.addTab(tbd_tab(), "\u2464 tbd")
        self.tabs.addTab(config_tab(), "\u2465 Edit config.ini")

        self.setLayout(self.layout)

if __name__ == '__main__':
    # Set the working directory to the script's directory
    os.chdir(os.path.dirname(os.path.abspath(__file__)))

    # Read the configuration file
    config = configparser.ConfigParser()
    config.read('config.ini')

    # Check the operating system
    os_name = platform.system()

    app = QApplication(sys.argv)
    ex = TabbedGUI()
    ex.show()
    sys.exit(app.exec_())