@echo off
setlocal

:: Schritt 1: Python installieren
echo Installing Python...
if not exist "%ProgramFiles%\Python39" (
    echo Downloading Python installer...
    curl -o python-installer.exe https://www.python.org/ftp/python/3.9.9/python-3.9.9-amd64.exe
    echo Running Python installer...
    start /wait python-installer.exe /quiet InstallAllUsers=1 PrependPath=1
    del python-installer.exe
) else (
    echo Python is already installed.
)

:: Schritt 2: Überprüfen, ob Python verfügbar ist
python --version >nul 2>&1
if errorlevel 1 (
    echo Python installation failed. Exiting...
    exit /b 1
)

:: Schritt 3: pip aktualisieren
echo Updating pip...
python -m pip install --upgrade pip

:: Schritt 4: Repository herunterladen und entpacken
:: Verzeichnis des aktuellen Skripts ermitteln
set "SCRIPT_DIR=%~dp0"

echo Downloading repository as ZIP to script directory...
curl -L -o "%SCRIPT_DIR%researchdesktop.zip" https://git.rwth-aachen.de/palkovits/researchdesktop/-/archive/main/researchdesktop-main.zip

echo Extracting repository in script directory...
powershell -Command "Expand-Archive -Path '%SCRIPT_DIR%researchdesktop.zip' -DestinationPath '%SCRIPT_DIR%' -Force"

:: Wechsel in den entpackten Ordner
set "EXTRACTED_FOLDER=%SCRIPT_DIR%researchdesktop-main"
if exist "%EXTRACTED_FOLDER%" (
    cd "%EXTRACTED_FOLDER%"
) else (
    echo Extraction failed. Exiting...
    exit /b 1
)

:: Schritt 5: Ordner auf den Desktop kopieren
echo Copying files to Desktop...
set "DESKTOP_PATH=%USERPROFILE%\Desktop"
xcopy "%CD%" "%DESKTOP_PATH%\ResearchDesktop" /E /I /Q /Y

:: Schritt 6: Abhängigkeiten installieren
echo Installing dependencies from requirements.txt...
cd "%DESKTOP_PATH%\ResearchDesktop"
python -m pip install -r requirements.txt

:: Schritt 7: Bereinigung
echo Cleaning up...
cd "%SCRIPT_DIR%"
del "%SCRIPT_DIR%researchdesktop.zip"
rmdir "%EXTRACTED_FOLDER%" /S /Q

:: Schritt 8: Fertig
echo Setup complete. The application has been copied to your Desktop.
pause