import configparser
import os

from PyQt5.QtWidgets import QWidget, QVBoxLayout, QTextEdit, QPushButton, QMessageBox

def config_tab():
    tab = QWidget()
    layout = QVBoxLayout()

    # Create a QTextEdit for the config content
    config_edit = QTextEdit()
    config_edit.setMinimumHeight(200)  # Set a minimum height for better visibility

    # Create a load button
    load_button = QPushButton('Load config.ini')
    load_button.clicked.connect(lambda: load_config(config_edit))

    # Create a save button
    save_button = QPushButton('Save config.ini')
    save_button.clicked.connect(lambda: save_config(config_edit.toPlainText()))

    # Add the QTextEdit, load button, and save button to the layout
    layout.addWidget(config_edit)
    layout.addWidget(load_button)
    layout.addWidget(save_button)
    tab.setLayout(layout)
    return tab

def load_config(config_edit):
    config = configparser.ConfigParser()
    config.read('config.ini')

    # Convert the config file to a string
    config_string = ""
    for section in config.sections():
        config_string += f"[{section}]\n"
        for key, value in config.items(section):
            config_string += f"{key} = {value}\n"
        config_string += "\n"

    config_edit.setText(config_string)
    QMessageBox.information(None, 'Success', 'Config file loaded successfully.')

def save_config(config_string):
    config = configparser.ConfigParser()
    config.read_string(config_string)

    with open('config.ini', 'w') as configfile:
        config.write(configfile)

    QMessageBox.information(None, 'Success', 'Config file saved successfully.')