from PyQt5.QtWidgets import QWidget, QVBoxLayout, QPushButton, QLineEdit, QLabel, QFileDialog, QMessageBox, QGridLayout, QDialog, QInputDialog
import json
import os

def edit_tab():
    tab = QWidget()
    tab_layout = QVBoxLayout()
    grid_layout = QGridLayout()

    # Dictionary to store the QLineEdit widgets for each JSON key
    json_fields = {}

    # Variable to store the path of the loaded JSON file
    loaded_file_path = None

    # Add a load button
    load_button = QPushButton("Load JSON")
    tab_layout.addWidget(load_button)

    # Add a save button
    save_button = QPushButton("Save JSON")
    tab_layout.addWidget(save_button)

    def load_json(file_path=None):
        nonlocal loaded_file_path
        if file_path:
            loaded_file_path = file_path
        else:
            options = QFileDialog.Options()
            file_name, _ = QFileDialog.getOpenFileName(tab, "Open JSON File", "", "JSON Files (*.json);;All Files (*)", options=options)
            if file_name:
                loaded_file_path = file_name

        if loaded_file_path:
            try:
                with open(loaded_file_path, 'r') as file:
                    data = json.load(file)
                    # Clear the grid layout
                    for i in reversed(range(grid_layout.count())): 
                        grid_layout.itemAt(i).widget().setParent(None)
                    # Add fields for each key-value pair in the JSON data
                    row = 0
                    for key, value in data.items():
                        label = QLabel(key)
                        if isinstance(value, dict):
                            nested_json_display = QLineEdit(json.dumps(value, indent=4))
                            button = QPushButton("Edit JSON")
                            button.clicked.connect(lambda _, k=key, v=value: edit_nested_json(k, v))
                            grid_layout.addWidget(label, row, 0)
                            grid_layout.addWidget(nested_json_display, row, 1)
                            grid_layout.addWidget(button, row, 2)
                            json_fields[key] = nested_json_display
                        else:
                            line_edit = QLineEdit(str(value))
                            grid_layout.addWidget(label, row, 0)
                            grid_layout.addWidget(line_edit, row, 1)
                            json_fields[key] = line_edit
                        row += 1
            except Exception as e:
                QMessageBox.critical(tab, "Error", f"Failed to load JSON file: {e}")

    def save_json():
        nonlocal loaded_file_path
        if loaded_file_path:
            try:
                # Create a dictionary from the form fields
                data = {}
                for key, widget in json_fields.items():
                    value = widget.text()
                    try:
                        data[key] = json.loads(value)
                    except json.JSONDecodeError:
                        data[key] = value
                with open(loaded_file_path, 'w') as file:
                    json.dump(data, file, indent=4)
                QMessageBox.information(tab, "Success", "JSON file saved successfully.")
                # Reload the JSON to update the display
                load_json(loaded_file_path)
            except Exception as e:
                QMessageBox.critical(tab, "Error", f"Failed to save JSON file: {e}")
        else:
            QMessageBox.warning(tab, "No File Loaded", "Please load a JSON file first.")

    def edit_nested_json(key, value):
        dialog = QDialog(tab)
        dialog.setWindowTitle(f"Edit JSON for {key}")
        dialog_layout = QVBoxLayout()
        nested_grid_layout = QGridLayout()

        nested_json_fields = {}

        row = 0
        for nested_key, nested_value in value.items():
            nested_label = QLabel(nested_key)
            nested_line_edit = QLineEdit(', '.join([os.path.basename(v) for v in nested_value]) if isinstance(nested_value, list) else str(nested_value))
            add_file_button = QPushButton("Add File")
            add_file_button.clicked.connect(lambda _, k=nested_key, v=nested_value: add_file_to_list(k, v, nested_json_fields))
            nested_grid_layout.addWidget(nested_label, row, 0)
            nested_grid_layout.addWidget(nested_line_edit, row, 1)
            nested_grid_layout.addWidget(add_file_button, row, 2)
            nested_json_fields[nested_key] = nested_line_edit
            row += 1

        save_button = QPushButton("Save")
        save_button.clicked.connect(lambda: save_nested_json(dialog, key, nested_json_fields))
        dialog_layout.addLayout(nested_grid_layout)
        dialog_layout.addWidget(save_button)

        # Add button to add new key-value pair
        add_kv_button = QPushButton("Add Key-Value Pair")
        add_kv_button.clicked.connect(lambda: add_key_value_pair(nested_json_fields, nested_grid_layout))
        dialog_layout.addWidget(add_kv_button)

        dialog.setLayout(dialog_layout)
        dialog.exec_()

    def add_file_to_list(nested_key, nested_value, nested_json_fields):
        options = QFileDialog.Options()
        file_names, _ = QFileDialog.getOpenFileNames(tab, "Select Files", "", "All Files (*)", options=options)
        if file_names:
            if not isinstance(nested_value, list):
                nested_value = []
            nested_value.extend(file_names)
            nested_json_fields[nested_key].setText(', '.join([os.path.basename(f) for f in nested_value]))

    def save_nested_json(dialog, key, nested_json_fields):
        nested_data = {}
        for nested_key, widget in nested_json_fields.items():
            value = widget.text()
            if ', ' in value:
                nested_data[nested_key] = value.split(', ')
            else:
                nested_data[nested_key] = value
        json_fields[key].setText(json.dumps(nested_data, indent=4))
        dialog.accept()
        # Update the main JSON field with the new nested JSON data
        json_fields[key].setText(json.dumps(nested_data, indent=4))
        # Save the updated main JSON
        save_json()

    def add_key_value_pair(nested_json_fields, nested_grid_layout):
        key, ok = QInputDialog.getText(tab, "Add Key-Value Pair", "Enter key:")
        if ok and key:
            value, ok = QInputDialog.getText(tab, "Add Key-Value Pair", "Enter value:")
            if ok:
                label = QLabel(key)
                line_edit = QLineEdit(value)
                row = nested_grid_layout.rowCount()
                nested_grid_layout.addWidget(label, row, 0)
                nested_grid_layout.addWidget(line_edit, row, 1)
                add_file_button = QPushButton("Add File")
                add_file_button.clicked.connect(lambda _, k=key, v=[]: add_file_to_list(k, v, nested_json_fields))
                nested_grid_layout.addWidget(add_file_button, row, 2)
                nested_json_fields[key] = line_edit

    load_button.clicked.connect(lambda: load_json())
    save_button.clicked.connect(save_json)

    tab_layout.addLayout(grid_layout)
    tab.setLayout(tab_layout)
    return tab