import configparser
import os

from PyQt5.QtWidgets import QWidget, QGridLayout, QLineEdit, QPushButton, QFileDialog, QMessageBox

def folder_tab():
    grid = QWidget()
    grid_layout = QGridLayout()

    # Create the fields for the layout
    project = QLineEdit()
    parent_folder = QLineEdit()

    # Set placeholders (hints) for the QLineEdit fields
    project.setPlaceholderText("Enter project name")
    parent_folder.setPlaceholderText("Select parent folder")

    # Add a button to open a file dialog for selecting the parent folder
    select_folder_button = QPushButton("Select Folder")
    select_folder_button.clicked.connect(lambda: select_folder(parent_folder))

    button2 = QPushButton("Create new project folder")

    # Add widgets to the grid layout
    grid_layout.addWidget(project, 0, 0, 1, 2)
    grid_layout.addWidget(parent_folder, 1, 0)
    grid_layout.addWidget(select_folder_button, 1, 1)
    grid_layout.addWidget(button2, 2, 0, 1, 2)

    grid.setLayout(grid_layout)

    button2.clicked.connect(lambda: clicked(project.text(), parent_folder.text()))

    return grid

def select_folder(parent_folder):
    folder = QFileDialog.getExistingDirectory(None, "Select Parent Folder")
    if folder:
        parent_folder.setText(folder)

def clicked(project_name, parent_folder):
    config = configparser.ConfigParser()
    config.read('config.ini')

    folder_structure = {key: value for key, value in config.items('FolderStructure')}
    
    global project_path  # make project path accessible from outside
    project_path = os.path.join(parent_folder, project_name)  # Use project_name and parent_folder here

    if not os.path.exists(project_path):
        try:
            os.makedirs(project_path)
            for folder in folder_structure.values():  # Iterate over values directly
                path = os.path.join(project_path, folder)
                os.makedirs(path)
            QMessageBox.information(None, "Success", f"Project folder '{project_name}' and subfolders created.")  # Show success message
        except Exception as e:
            QMessageBox.critical(None, "Error", f"An error occurred: {e}")  # Show error message
    else:
        reply = QMessageBox.question(None, "Warning", f"Project folder '{project_name}' already exists. Do you want to create the missing subfolders?",
                                     QMessageBox.Yes | QMessageBox.No, QMessageBox.No)

        if reply == QMessageBox.Yes:
            try:
                for folder in folder_structure.values():
                    path = os.path.join(project_path, folder)
                    if not os.path.exists(path):
                        os.makedirs(path)
                QMessageBox.information(None, "Success", "Missing subfolders created.")
            except Exception as e:
                QMessageBox.critical(None, "Error", f"An error occurred: {e}")
        else:
            QMessageBox.information(None, "Info", "Folder creation cancelled.")
    return project_path  # return project_path

