import configparser
import platform
import subprocess
import os
import getpass

from PyQt5.QtWidgets import QWidget, QGridLayout, QVBoxLayout, QLineEdit, QPushButton, QLabel, QMessageBox

def mount_tab(config):
    grid = QWidget()
    grid_layout = QGridLayout()

    # Check if there is a server, share and user entry in the config
    if 'Settings' in config and 'server' in config['Settings']:
        server = QLineEdit(config['Settings']['server'])
    else:
        server = QLineEdit()    

    if 'Settings' in config and 'share' in config['Settings']:
        share = QLineEdit(config['Settings']['share'])
    else:
        share = QLineEdit()
    
    if 'User' in config and 'username' in config['User']:
        user = QLineEdit(config['User']['username'])
    else:
        user = QLineEdit()

    # Create the other fields for the layout
    label1 = QLabel("Server to connect to:")
    label2 = QLabel("Share to mount:")
    label3 = QLabel("Username:")
    label4 = QLabel("Password:")
    button1 = QPushButton("Mount share")
    
    # Create the password field
    password = QLineEdit()
    password.setEchoMode(QLineEdit.Password)

    # Add widgets to the grid layout
    grid_layout.addWidget(label1, 0, 0)
    grid_layout.addWidget(server, 0, 1)
    grid_layout.addWidget(label2, 1, 0)
    grid_layout.addWidget(share, 1, 1)
    grid_layout.addWidget(label3, 2, 0)
    grid_layout.addWidget(user, 2, 1)
    grid_layout.addWidget(label4, 3, 0)
    grid_layout.addWidget(password, 3, 1)
    grid_layout.addWidget(button1, 4, 0, 1, 2)

    grid.setLayout(grid_layout)

    # Connect the button click event to the mount_share method
    button1.clicked.connect(lambda: mount_share(server.text(), share.text(), user.text(), password.text()))

    return grid

def mount_share(server, share, user, password):
    os_name = platform.system()
    if os_name == 'Darwin':
        try:
            # Check if the mount point exists, create it if it doesn't
            mount_point = f"/Users/{getpass.getuser()}/{share}"
            if not os.path.exists(mount_point):
                os.makedirs(mount_point)
            
            # Construct the mount command for macOS
            mount_cmd = f"mount_smbfs //{user}:{password}@{server}/{share} {mount_point}"
            subprocess.run(mount_cmd, shell=True, check=True)
            QMessageBox.information(None, "Success", f"Share '{share}' mounted successfully on macOS.")
        except subprocess.CalledProcessError as e:
            QMessageBox.critical(None, "Error", f"Failed to mount share '{share}' on macOS: {e}")
        except Exception as e:
            QMessageBox.critical(None, "Error", f"An error occurred: {e}")
    elif os_name == 'Windows':
        try:
            # Construct the mount command for Windows with drive letter P
            mount_cmd = f"net use P: \\\\{server}\\{share} /user:{user} {password}"
            subprocess.run(mount_cmd, shell=True, check=True)
            QMessageBox.information(None, "Success", f"Share '{share}' mounted successfully on Windows.")
        except subprocess.CalledProcessError as e:
            QMessageBox.critical(None, "Error", f"Failed to mount share '{share}' on Windows: {e}")
        except Exception as e:
            QMessageBox.critical(None, "Error", f"An error occurred: {e}")
    else:
        QMessageBox.warning(None, "Unsupported OS", "This feature is only supported on macOS (Darwin) and Windows.")